<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>FileControl</name>
    <message>
        <location filename="../src/filecontrol.cpp" line="781"/>
        <source>Fullscreen</source>
        <translation>Полный Экран</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="785"/>
        <source>Exit fullscreen</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="789"/>
        <source>Extract text</source>
        <translation>Извлечь текст</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="793"/>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="797"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="801"/>
        <location filename="../src/filecontrol.cpp" line="893"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="805"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="809"/>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="813"/>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="817"/>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="821"/>
        <source>Display in file manager</source>
        <translation>Отобразить в  файловом менеджере </translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="825"/>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="829"/>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="833"/>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="837"/>
        <source>Zoom in</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="841"/>
        <source>Zoom out</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="845"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="849"/>
        <source>Print</source>
        <translation>Распечатать</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="873"/>
        <source>Image Viewing</source>
        <translation>Просмотр Изображений</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="877"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="881"/>
        <source>Display shortcuts</source>
        <translation>Показать сочетания клавиш</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="889"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="897"/>
        <source>Select all</source>
        <translation>Выбрать все</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="905"/>
        <source>Live Text</source>
        <translation>Живой текст</translation>
    </message>
</context>
<context>
    <name>InformationDialog</name>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="74"/>
        <source>Basic info</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="98"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="124"/>
        <source>Date captured</source>
        <translation>Дата захвата</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="131"/>
        <source>Date modified</source>
        <translation>Дата изменения</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="141"/>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="154"/>
        <source>Aperture</source>
        <translation>Диафрагма</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="162"/>
        <source>Exposure program</source>
        <translation>Программа экспозиции</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="169"/>
        <source>Focal length</source>
        <translation>Фокусное расстояние</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="175"/>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="182"/>
        <source>Exposure mode</source>
        <translation>Режим экспозиции</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="188"/>
        <source>Exposure time</source>
        <translation>Время экспозиции</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="194"/>
        <source>Flash</source>
        <translation>Вспышка</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="201"/>
        <source>Flash compensation</source>
        <translation>Компенсация вспышки</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="214"/>
        <source>Colorspace</source>
        <translation>Цветовое пространство</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="221"/>
        <source>Metering mode</source>
        <translation>Режим замера экспозиции</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="228"/>
        <source>White balance</source>
        <translation>Баланс белого</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="246"/>
        <source>Lens model</source>
        <translation>Модель линзы</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="87"/>
        <source>File name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="105"/>
        <source>Dimensions</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="112"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="207"/>
        <source>Max aperture</source>
        <translation>Макс диафрагма</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="239"/>
        <source>Device model</source>
        <translation>Модель устройства</translation>
    </message>
</context>
<context>
    <name>LiveTextWidget</name>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="155"/>
        <source>Copy (Ctrl+C)</source>
        <translation>Копировать (Ctrl+C)</translation>
    </message>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="172"/>
        <source>Select all (Ctrl+A)</source>
        <translation>Выбрать все (Ctrl+A)</translation>
    </message>
</context>
<context>
    <name>MainStack</name>
    <message>
        <location filename="../qml/MainStack.qml" line="129"/>
        <source>Select pictures</source>
        <translation>Выберите фотографии</translation>
    </message>
</context>
<context>
    <name>NonexistImageDelegate</name>
    <message>
        <location filename="../qml/ImageDelegate/NonexistImageDelegate.qml" line="43"/>
        <source>Image file not found</source>
        <translation>Файл изображения не найден</translation>
    </message>
</context>
<context>
    <name>OpenImageWidget</name>
    <message>
        <location filename="../qml/OpenImageWidget.qml" line="35"/>
        <source>Open Image</source>
        <translation>Открыть  Изображение</translation>
    </message>
</context>
<context>
    <name>PropertyActionItemDelegate</name>
    <message>
        <location filename="../qml/InformationDialog/PropertyActionItemDelegate.qml" line="95"/>
        <source>The file already exists, please use another name</source>
        <translation>Файл уже существует, пожалуйста, используйте другое имя</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Image Viewer</source>
        <translation>Просмотр Изображений</translation>
    </message>
    <message>
        <location filename="../src/unionimage/unionimage_global.h" line="102"/>
        <source>day</source>
        <translation>д</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Просмотр Изображений - это инструмент для просмотра изображений с современным интерфейсом и плавной работой.</translation>
    </message>
</context>
<context>
    <name>ReName</name>
    <message>
        <location filename="../qml/ReName.qml" line="70"/>
        <source>Input a new name</source>
        <translation>Введите новое имя</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="85"/>
        <source>The file already exists, please use another name</source>
        <translation>Файл уже существует, пожалуйста, используйте другое имя</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="141"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="123"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>RemoveDialog</name>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="71"/>
        <source>Cannot move &quot;%1&quot; to the trash. Do you want to permanently delete it?</source>
        <translation>Не удается переместить «%1» в корзину. Вы хотите удалить его навсегда?</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="89"/>
        <source>This action cannot be undone</source>
        <translation>Это действие нельзя отменить</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="101"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="111"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>SliderShow</name>
    <message>
        <location filename="../qml/SliderShow.qml" line="155"/>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <location filename="../qml/SliderShow.qml" line="223"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <location filename="../qml/SliderShow.qml" line="223"/>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="188"/>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="203"/>
        <location filename="../qml/SliderShow.qml" line="244"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="173"/>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="148"/>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="209"/>
        <source>Original size</source>
        <translation>Оригинальный размер</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="227"/>
        <source>Fit to window</source>
        <translation>По размеру окна</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="244"/>
        <source>Rotate</source>
        <translation>Повернуть</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="517"/>
        <source>Extract text</source>
        <translation>Извлечь текст</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="536"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>ViewRightMenu</name>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Fullscreen</source>
        <translation>Полный Экран</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Exit fullscreen</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="57"/>
        <source>Print</source>
        <translation>Распечатать</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="76"/>
        <source>Extract text</source>
        <translation>Извлечь текст</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="96"/>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="117"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="137"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="156"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="183"/>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="203"/>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Show navigation window</source>
        <translation>Показать окно навигации</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Hide navigation window</source>
        <translation>Скрыть окно навигации</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="243"/>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="263"/>
        <source>Display in file manager</source>
        <translation>Отобразить в  файловом менеджере </translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="280"/>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
</context>
<context>
    <name>ViewTopTitle</name>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="189"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Просмотр Изображений - это инструмент для просмотра изображений с современным интерфейсом и плавной работой.</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="191"/>
        <source>Image Viewer</source>
        <translation>Просмотр Изображений</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="167"/>
        <source>Open image</source>
        <translation>Открытое изображение</translation>
    </message>
</context>
</TS>
